package com.jd.ai.asr.demo;

import android.content.Context;
import android.content.pm.PackageManager;

import org.json.JSONArray;
import org.json.JSONException;
import org.json.JSONObject;

import java.io.PrintWriter;
import java.io.StringWriter;
import java.net.UnknownHostException;
import java.text.SimpleDateFormat;
import java.util.Arrays;
import java.util.Date;


public class MaeLogInfoUtils {
    private static final char TOP_LEFT_CORNER = '┌';
    private static final char BOTTOM_LEFT_CORNER = '└';
    private static final char MIDDLE_CORNER = '├';
    private static final char HORIZONTAL_LINE = '│';
    private static final String DOUBLE_DIVIDER = "────────────────────────";
    private static final String SINGLE_DIVIDER = "┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄";
    private static final String TOP_BORDER = "┌────────────────────────────────────────────────";
    private static final String BOTTOM_BORDER = "└────────────────────────────────────────────────";
    private static final String MIDDLE_BORDER = "├┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄┄";
    private static final String CONTENT_BORDER = "│ ";
    private static String SEPERATOR = System.getProperty("line.separator");
    private static String cacheDeviceInfo;

    public MaeLogInfoUtils() {
    }

    public static String getJsonLog(String json) {
        byte JSON_INDENT = 2;

        try {
            json = json.trim();
            if(json.startsWith("{")) {
                JSONObject jsonObject = new JSONObject(json);
                return jsonObject.toString(JSON_INDENT);
            } else if(json.startsWith("[")) {
                JSONArray jsonArray = new JSONArray(json);
                return jsonArray.toString(JSON_INDENT);
            } else {
                return null;
            }
        } catch (JSONException var3) {
            return null;
        }
    }



    private static String getHeaderInfo(String tag, String[] originHeaderInfo) {
        StringBuilder builder = new StringBuilder();
        builder.append("│ ").append("Tag: ").append(tag).append(SEPERATOR).append("│ ").append("Thread: ").append(Thread.currentThread().getName()).append(SEPERATOR);
        if(originHeaderInfo != null) {
            String[] var3 = originHeaderInfo;
            int var4 = originHeaderInfo.length;

            for(int var5 = 0; var5 < var4; ++var5) {
                String info = var3[var5];
                builder.append("│ ").append(info).append(SEPERATOR);
            }
        }

        return builder.toString();
    }

    public static String getStackTraceString(Throwable tr) {
        if(tr == null) {
            return "";
        } else {
            for(Throwable t = tr; t != null; t = t.getCause()) {
                if(t instanceof UnknownHostException) {
                    return "";
                }
            }

            StringWriter sw = new StringWriter();
            PrintWriter pw = new PrintWriter(sw);
            tr.printStackTrace(pw);
            pw.flush();
            return sw.toString();
        }
    }

    private static String getMessageInfo(Object object) {
        String msg = toString(object);
        String[] lines = msg.split(System.getProperty("line.separator"));
        StringBuilder res = new StringBuilder();
        String[] var4 = lines;
        int var5 = lines.length;

        for(int var6 = 0; var6 < var5; ++var6) {
            String line = var4[var6];
            res.append("│ ").append(line).append(SEPERATOR);
        }

        return res.toString();
    }

    private static String toString(Object object) {
        return object == null?"null":(!object.getClass().isArray()?object.toString():(object instanceof boolean[]? Arrays.toString((boolean[])((boolean[])object)):(object instanceof byte[]?Arrays.toString((byte[])((byte[])object)):(object instanceof char[]?Arrays.toString((char[])((char[])object)):(object instanceof short[]?Arrays.toString((short[])((short[])object)):(object instanceof int[]?Arrays.toString((int[])((int[])object)):(object instanceof long[]?Arrays.toString((long[])((long[])object)):(object instanceof float[]?Arrays.toString((float[])((float[])object)):(object instanceof double[]?Arrays.toString((double[])((double[])object)):(object instanceof Object[]?Arrays.deepToString((Object[])((Object[])object)):"Couldn't find a correct type for the object"))))))))));
    }

    private static String getLocalVersionName(Context context) {
        String packageName = context.getPackageName();
        String VERSION_NAME = "1.0";

        try {
            VERSION_NAME = context.getPackageManager().getPackageInfo(packageName, 0).versionName;
            return VERSION_NAME;
        } catch (PackageManager.NameNotFoundException var4) {
            return VERSION_NAME;
        }
    }

    private static String getFormatString(long timeMillis, String format) {
        return (new SimpleDateFormat(format)).format(new Date(timeMillis));
    }

}
