package com.jd.ai.asr.demo;

import android.Manifest;
import android.os.Bundle;
import android.os.Handler;
import android.os.Looper;
import android.util.Log;
import android.view.View;
import android.widget.Button;
import android.widget.TextView;
import android.widget.Toast;

import com.jd.ai.asr.ASROperator;
import com.jd.ai.common.LogUtil;
import com.jd.ai.manager.EngineType;
import com.jd.ai.manager.SpeechConstant;
import com.jd.ai.manager.SpeechEvent;
import com.jd.ai.manager.SpeechListener;
import com.jd.ai.manager.SpeechManager;
import com.jd.ai.manager.SpeechUtility;

import org.json.JSONArray;
import org.json.JSONException;
import org.json.JSONObject;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

public class MainActivity extends BaseActivity implements SpeechListener {
    private boolean isRecording;
    private boolean isRealTimeRecording;
    private SpeechManager asrManager, ttsManager;
    private TextView textView;
    private TextView volumeView;
    private Handler mainHandler = new Handler(Looper.getMainLooper());
    Button button;


    @Override
    public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_main);

        volumeView = findViewById(R.id.volume);
        textView = findViewById(R.id.text);

        LogUtil.setLogLevel(Log.DEBUG);
        asrManager = SpeechUtility.create(this, EngineType.ASR);
        asrManager.setListener(this);

        button = findViewById(R.id.realTimeBtn);

        button.setOnClickListener( new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                requetPermission(new String[]{Manifest.permission.RECORD_AUDIO, Manifest.permission.ACCESS_NETWORK_STATE,
                        Manifest.permission.INTERNET, Manifest.permission.WRITE_EXTERNAL_STORAGE}, new PermissionListener() {
                    @Override
                    public void onSuccess() {
                        if (isRecording) {
                            stopAsr();
                            button.setText("开始录音");
                        } else {
                            startAsr();
                            button.setText("结束录音");
                            textView.setText("识别中...");
                        }
                        isRecording = !isRecording;
                    }

                    @Override
                    public void onFail(List<String> deiedPermission) {
                        for(String permission : deiedPermission){

                            Toast.makeText(MainActivity.this,"权限被拒绝: " + permission,Toast.LENGTH_LONG).show();
                        }
                    }
                });

            }
        });

    }

    private  void  startAsr() {
        if (asrManager != null) {
            Map map = new HashMap();
            //APPkey和SecretKey请参考文档鉴权说明申请 
            map.put(SpeechContent.APPKEY,”124345”);
            map.put(SpeechContent.SECRETKEY,"12345“)；
            map.put(SpeechConstant.URL,"https://aiapi.jd.com/jdai/asr");
            map.put(SpeechConstant.SAMPLE_RATE, 16000);
            map.put(SpeechConstant.VAD_RES, "assets://vad.bin");

            map.put(SpeechConstant.LOCAL_VAD_ENABLE,true);
            asrManager.send(ASROperator.START, new JSONObject(map).toString());
        }
    }

    private void stopAsr() {
        if (asrManager != null) {
            asrManager.send(ASROperator.STOP, null);
        }
    }

    @Override
    protected void onDestroy() {
        super.onDestroy();
        asrManager.send(ASROperator.CANCEL, null);
    }

    @Override
    public void onEvent(SpeechEvent event, final String result, byte[] data) {
        switch (event){
            case SPEECH_START:
                break;
            case SPEECH_BEGIN:
                break;
            case SPEECH_END:
                break;
            case SPEECH_PARITAL_RESULT:
                mainHandler.post(new Runnable() {
                    @Override
                    public void run() {
                        textView.setText("临时结果：\n"+ MaeLogInfoUtils.getJsonLog(result));
                    }
                });

                break;
            case SPEECH_RESULT:
                isRecording = false;
                mainHandler.post(new Runnable() {
                    @Override
                    public void run() {
                        button.setClickable(true);
                        button.setText("开始录音");
                        button.setClickable(true);
                        textView.setText("最终结果 \n"+ MaeLogInfoUtils.getJsonLog(result));
                        String  res = getAsrResult(result);
                    }
                });


                break;
            case SPEECH_VOLUME:
                mainHandler.post(new Runnable() {
                    @Override
                    public void run() {
                        try {
                            volumeView.setText("音量："+ new JSONObject(result).getString("volume"));
                        } catch (JSONException e){
                            e.printStackTrace();
                        }
                    }
                });

                break;
            case TTS_SYNTHESIZE_FINISH :
                LogUtil.d("tts"," tts finish");
                break;
        }
    }

    private  String  getAsrResult(String  result){
        try{
            JSONObject  object = new JSONObject(result);
            int  errCode = Integer.valueOf(object.getString("err_code"));
            if( errCode != 0){
                return  null;
            }
            JSONArray array = object.getJSONArray("content");
            JSONObject  resJson = array.getJSONObject(0);
            String  text = resJson.getString("text");
            return  text;
        }catch (JSONException e){
            e.printStackTrace();
        }
        return   null;
    }



}
